@@ -41,6 +41,7 @@ circos.dendrogram = function(dend, maxy) {
     draw.d(dend, maxy)
 }
 
+op = par(no.readonly = TRUE)
 
 library(circlize)
 mat = matrix(rnorm(100*10), nrow = 10, ncol = 100)
@@ -79,4 +80,7 @@ circos.trackPlotRegion(ylim = c(0, maxy), bg.border = NA, track.height = 0.3, pa
     circos.dendrogram(dend.col, maxy)
     
 })
-circos.clear()
\ No newline at end of file
+circos.clear()
+
+
+par(op)
